@@ -1,13 +1,12 @@
 pub use crate::compiler::{
     compile, CaoIr, Card, CompilationError, CompilationErrorPayload, CompileOptions, Lane,
 };
-pub use crate::instruction::Instruction;
 pub use crate::procedures::*;
 pub use crate::program::*;
 pub use crate::traits::*;
 pub use crate::value::*;
 pub use crate::{
-    collections::key_map::Key,
+    collections::key_map::Handle,
     subprogram_description,
     vm::{runtime::FieldTable, Vm},
     InputString, NodeId, StrPointer, SubProgram, SubProgramType,
